@@ -353,7 +353,7 @@ auth_check_idle (GSLockPlug *plug)
 
                 if (loop_counter < MAX_FAILURES) {
                         gs_debug ("Authentication failed, retrying (%u)", loop_counter);
-                        g_timeout_add (3000, (GSourceFunc)reset_idle_cb, plug);
+                        g_timeout_add_seconds (3, (GSourceFunc)reset_idle_cb, plug);
                 } else {
                         gs_debug ("Authentication failed, quitting (max failures)");
                         again = FALSE;
@@ -361,7 +361,7 @@ auth_check_idle (GSLockPlug *plug)
                          * terminates us after it has finished the dialog shake. Time out
                          * after 5 seconds and quit anyway if this doesn't happen though */
                         g_idle_add ((GSourceFunc)response_request_quit, NULL);
-                        g_timeout_add (5000, (GSourceFunc)quit_timeout_cb, NULL);
+                        g_timeout_add_seconds (5, (GSourceFunc)quit_timeout_cb, NULL);
                 }
         }
 
@@ -539,19 +539,13 @@ main (int    argc,
         char   *nolock_reason = NULL;
 
 #ifdef ENABLE_NLS
-        bindtextdomain (GETTEXT_PACKAGE, "/usr/share/cinnamon/locale");
+        bindtextdomain (GETTEXT_PACKAGE, "/usr/share/locale");
 # ifdef HAVE_BIND_TEXTDOMAIN_CODESET
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 # endif
         textdomain (GETTEXT_PACKAGE);
 #endif
 
-        if (! g_thread_supported ()) {
-                g_thread_init (NULL);
-        }
-
-        g_type_init ();
-
         gs_profile_start (NULL);
 
         if (! privileged_initialization (&argc, argv, verbose)) {
